@@ -34,7 +34,7 @@ SOFTWARE.
 
 //! MoCkInG SpOnGeBoB SqUaRePaNtS TeXt gEnErAtOr.
 
-use rand::{prelude::ThreadRng, Rng};
+use fastrand::bool;
 use std::{env, error::Error, fs::File, io::Read};
 
 /// The necessary configurations for initializing spongmock.
@@ -85,8 +85,7 @@ impl Config {
 
 /// Returns a random boolean value.
 pub fn rand_bool() -> bool {
-    let mut rng: ThreadRng = rand::thread_rng();
-    rng.gen()
+    bool()
 }
 
 fn mock_refstr(s: &str, randomize: bool) -> String {
